==> darfix-1.1.0-py3-none-any.whl: darfix/gui/PCAWidget.py <==
__authors__ = ["J. Garriga"]
__license__ = "MIT"
__date__ = "22/12/2020"

import numpy

from silx.gui import qt
from silx.gui.plot import Plot1D

from .operationThread import OperationThread
from darfix import dtypes


class PCAWidget(qt.QMainWindow):
    """
    Widget to apply PCA to a set of images and plot the eigenvalues found.
    """

    sigComputed = qt.Signal()

    def __init__(self, parent=None):
        qt.QWidget.__init__(self, parent)

        self._plot = Plot1D()
        self._plot.setDataMargins(0.05, 0.05, 0.05, 0.05)
        self._plot.setGraphXLabel("Components")
        self._plot.setGraphYLabel("Singular values")
        self.setCentralWidget(self._plot)

    def _computePCA(self):
        try:
            self._thread = OperationThread(self, self._dataset.pca)
            self._thread.setArgs(return_vals=True, indices=self.indices)
            self._thread.finished.connect(self._updateData)
            self._thread.start()
        except Exception as e:
            raise e

    def setDataset(self, owdataset: dtypes.OWDataset):
        self._parent = owdataset.parent
        self._dataset = owdataset.dataset
        self.indices = owdataset.indices
        self.bg_indices = owdataset.bg_indices
        self.bg_dataset = owdataset.bg_dataset
        self._plot.setGraphTitle(
            "Components representation of the dataset " + self._dataset.title
        )
        self._computePCA()

    def _updateDataset(self, widget, dataset):
        self._parent._updateDataset(widget, dataset)
        self._dataset = dataset

    def _updateData(self):
        """
        Plots the eigenvalues.
        """
        self._thread.finished.disconnect(self._updateData)
        vals = self._thread.data
        self._plot.show()
        self._plot.addCurve(numpy.arange(len(vals)), vals, symbol=".", linestyle=" ")
        self.sigComputed.emit()

==> darfix-2.0.0.dev3-py3-none-any.whl: darfix/gui/PCAWidget.py <==
from __future__ import annotations
import numpy

from silx.gui import qt
from silx.gui.plot import Plot1D

from .operationThread import OperationThread
from darfix import dtypes


class PCAPlot(Plot1D):
    def __init__(self, parent=None, backend=None):
        super().__init__(parent, backend)
        self.setDataMargins(0.05, 0.05, 0.05, 0.05)
        self.setGraphXLabel("Components")
        self.setGraphYLabel("Singular values")

    def setData(self, vals: numpy.ndarray, title=None):
        if not isinstance(vals, numpy.ndarray):
            raise TypeError(
                f"vals should be an instance of {numpy.ndarray}. got {type(vals)} instead"
            )
        if title is None:
            title = ""
        self.setGraphTitle("Components representation of the dataset " + title)
        self.addCurve(numpy.arange(len(vals)), vals, symbol=".", linestyle=" ")


class PCAWidget(qt.QMainWindow):
    """
    Widget to apply PCA to a set of images and plot the eigenvalues found.
    """

    sigComputed = qt.Signal()

    def __init__(self, parent=None):
        qt.QWidget.__init__(self, parent)

        self._plot = PCAPlot()
        self.setCentralWidget(self._plot)

    def _computePCA(self):
        try:
            self._thread = OperationThread(self, self._dataset.pca)
            self._thread.setArgs(return_vals=True, indices=self.indices)
            self._thread.finished.connect(self._updateData)
            self._thread.start()
        except Exception as e:
            raise e

    def setDataset(self, owdataset: dtypes.OWDataset):
        self._parent = owdataset.parent
        self._dataset = owdataset.dataset
        self.indices = owdataset.indices
        self.bg_indices = owdataset.bg_indices
        self.bg_dataset = owdataset.bg_dataset
        self._computePCA()

    def _updateDataset(self, widget, dataset):
        self._parent._updateDataset(widget, dataset)
        self._dataset = dataset

    def _updateData(self):
        """
        Plots the eigenvalues.
        """
        self._thread.finished.disconnect(self._updateData)
        vals = self._thread.data
        self._plot.setData(vals, self._dataset.title)
        self.sigComputed.emit()
